The Tutorial
============

As with many interactive packages, getting started with yt can be a bit
daunting.  Following this tutorial we'll walk through the intepreter, get used
to some of the ways that yt works, and performing some common (and
not-so-common) tasks.

Contents:

.. toctree::
   :maxdepth: 2

   getting_started
   basic_objects
   derived_fields
   profiles
   automated_plotting
   advanced_objects
   projections
   example_script
   using_reason
